package com.example.controller;

import com.example.config.annotation.IgnoreAuth;
import com.example.entity.OtnAreaEntity;
import com.example.entity.WzHouseUseEntity;
import com.example.entity.vo.WzHouseUseVo;
import com.example.service.WzHouseUseService;
import com.example.service.WzOtnAreaService;
import com.example.utils.PageMap;
import com.example.utils.PageUtils;
import com.example.utils.Query;
import com.example.utils.R;
import com.example.utils.excel.ExcelExport;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.text.DateFormat;
import java.text.DecimalFormat;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 房屋租入（租入用途管理）
 */
@RestController
@RequestMapping("/house-car/house/dist/api/WzHouseUse")
public class WzHouseUseController {

    @Autowired
    private WzHouseUseService wzHouseUseService;
    @Autowired
    private WzOtnAreaService otnAreaService;

    @RequestMapping("/list")
    @IgnoreAuth
    public R list(@RequestBody PageMap pageMap) {
        //查询列表数据
        Query query = new Query(pageMap);
        List<WzHouseUseEntity> list = wzHouseUseService.queryList(pageMap.getMap());
        int total = wzHouseUseService.queryTotal(query);
        PageUtils pageUtil = new PageUtils(list, total, query.getLimit(), query.getPage());
        return R.ok().put("page", pageUtil);
    }

    @RequestMapping("/echartList")
    @IgnoreAuth
    public R echartList(@RequestBody PageMap pageMap) {
        //查询列表数据
        Query query = new Query(pageMap);
        List<WzHouseUseEntity> wzHouseContracEntityList = wzHouseUseService.queryList(pageMap.getMap());

        Map<String,List<WzHouseUseEntity>> cityMap=new HashMap<>();
        for (WzHouseUseEntity leaveUseVo : wzHouseContracEntityList) {
            List<WzHouseUseEntity> list;
            if(cityMap.get(leaveUseVo.getCity())!=null){
                list=cityMap.get(leaveUseVo.getCity());
                list.add(leaveUseVo);
            }else{
                list=new ArrayList<>();
                list.add(leaveUseVo);
            }
            cityMap.put(leaveUseVo.getCity(),list);
        }

        List<WzHouseUseVo> resultList=new ArrayList<>();
        List<WzHouseUseVo> cityList=new ArrayList<>();

        int allyingYe=0;
        int allbanGong=0;
        int alltongXin=0;
        int allother=0;
        int allall=0;
        for(Map.Entry<String,List<WzHouseUseEntity>> entry:cityMap.entrySet()){
            List<WzHouseUseEntity> list=entry.getValue();

            if (list.get(0).getCounty().equals("全省")) {
                continue;
            }
            //县的Map集合
            Map<String, List<WzHouseUseEntity>> countyMap = new HashMap<>();
            for (WzHouseUseEntity leaveUseVo : list) {
                if (leaveUseVo.getCounty() == null || leaveUseVo.getCounty().equals("")) {
                    continue;
                }
                if (countyMap.get(leaveUseVo.getCounty()) != null) {
                    list = countyMap.get(leaveUseVo.getCounty());
                    list.add(leaveUseVo);
                } else {
                    list = new ArrayList<>();
                    list.add(leaveUseVo);
                }
                countyMap.put(leaveUseVo.getCounty(), list);
            }

            int cityyingYe=0;
            int citybanGong=0;
            int citytongXin=0;
            int cityother=0;
            int cityall=0;
            List<WzHouseUseVo> countyList=new ArrayList<>();
            for (Map.Entry<String, List<WzHouseUseEntity>> countyEntry : countyMap.entrySet()) {
                int yingYe=0;
                int banGong=0;
                int tongXin=0;
                int other=0;
                int all=0;
                for (WzHouseUseEntity leaveUseVo : countyEntry.getValue()) {
                    if(leaveUseVo.getRentalUse()!=null){
                        if(leaveUseVo.getRentalUse().equals("通信设施机房")){
                            tongXin+=1;
                            citytongXin+=1;
                            alltongXin+=1;
                        }
                        else if(leaveUseVo.getRentalUse().equals("营业")){
                            yingYe+=1;
                            cityyingYe+=1;
                            allyingYe+=1;
                        }
                        else if(leaveUseVo.getRentalUse().equals("其他租入用途")){
                            other+=1;
                            cityother+=1;
                            allother+=1;
                        }
                        else if(leaveUseVo.getRentalUse().equals("办公")){
                            banGong+=1;
                            citybanGong+=1;
                            allbanGong+=1;
                        }
                        all+=1;
                        cityall+=1;
                        allall+=1;
                    }
                }
                WzHouseUseVo wzHouseInCustomerEntity = new WzHouseUseVo();
                wzHouseInCustomerEntity.setYingYe(yingYe);
                wzHouseInCustomerEntity.setCity(countyEntry.getKey());
                wzHouseInCustomerEntity.setBanGong(banGong);
                wzHouseInCustomerEntity.setAll(all);
                wzHouseInCustomerEntity.setTongXin(tongXin);
                wzHouseInCustomerEntity.setOther(other);
                countyList.add(wzHouseInCustomerEntity);
            }
            List<WzHouseUseVo> orderCountyList=new ArrayList<>();
            try{
                //对countList 进行排序
                String city=list.get(0).getCity();
                if(city.contains("市")){
                    city=city.split("市")[0];
                }
                OtnAreaEntity area=otnAreaService.queryObject(city);
                List<OtnAreaEntity> countyAreaList=otnAreaService.getCityOption(area.getId());
                int i=0;
                for (OtnAreaEntity otnAreaEntity : countyAreaList) {
                    for (WzHouseUseVo wzCity : countyList) {
                        if(wzCity.getCity().contains(otnAreaEntity.getName())){
                            i++;
                            wzCity.setFlag(i%2==0);
                            orderCountyList.add(wzCity);
                        }
                    }
                }
            }catch (Exception e){
                orderCountyList=countyList;
                e.printStackTrace();
            }

            WzHouseUseVo wzHouseInCustomerEntity = new WzHouseUseVo();
            wzHouseInCustomerEntity.setCity(entry.getKey());
            wzHouseInCustomerEntity.setYingYe(cityyingYe);
            wzHouseInCustomerEntity.setBanGong(citybanGong);
            wzHouseInCustomerEntity.setAll(cityall);
            wzHouseInCustomerEntity.setTongXin(citytongXin);
            wzHouseInCustomerEntity.setOther(cityother);
            wzHouseInCustomerEntity.setChildren(orderCountyList);
            cityList.add(wzHouseInCustomerEntity);
        }


        //对cityList 进行排序
        List<OtnAreaEntity> areaList=otnAreaService.getCityOption("018");
        List<WzHouseUseVo> orderList=new ArrayList<>();
        int i=0;
        for (OtnAreaEntity otnAreaEntity : areaList) {
            for (WzHouseUseVo wzCity : cityList) {
                if(wzCity.getCity().contains(otnAreaEntity.getName())){
                    wzCity.setFlag(i%2==0);
                    i++;
                    orderList.add(wzCity);
                }
            }
        }

        WzHouseUseVo province=new WzHouseUseVo();
        province.setCity("全省");
        province.setYingYe(allyingYe);
        province.setBanGong(allbanGong);
        province.setAll(allall);
        province.setTongXin(alltongXin);
        province.setOther(allother);
        province.setChildren(orderList);
        if(orderList.size()>0){
            resultList.add(province);
        }
        int total = wzHouseUseService.queryTotal(query);
        PageUtils pageUtil = new PageUtils(resultList, total, query.getLimit(), query.getPage());
        return R.ok().put("page", pageUtil);
    }

    /**
     * 清单excel
     */
    @GetMapping("/excel")
    @IgnoreAuth
    public void excel(String name,String buildingNameAlias,String city,String county, HttpServletResponse response) {
        Map<String,Object> map1=new HashMap<>();
        if(buildingNameAlias!=null){
            map1.put("buildingNameAlias",buildingNameAlias);
        }
        if(city!=null){
            map1.put("city",city);
        }
        if(county!=null){
            map1.put("county",county);
        }

        DateFormat df = new SimpleDateFormat("yyyyMMdd");
        ExcelExport ee1 = new ExcelExport("报表" + df.format(new Date()));

        //判定是闲置管理还是记录
        if(name.contains("出租合同统计")){
//            responseTab1(df,ee1,map1);
            ee1.export(response);
        }else if(name.contains("出租合同记录")){
            responseTab2(df,ee1,map1);
            ee1.export(response);
        }


    }

//    public void responseTab1(DateFormat df, ExcelExport ee1, Map<String, Object> map1){
//        List<WzHouseUseEntity> wzHouseContracEntityList = wzHouseUseService.queryList(map1);
//
//        WzHouseContracEntity province=new WzHouseContracEntity();
//        province.setCity("全省");
//
//        Map<String,List<WzHouseUseEntity>> map=new HashMap<>();
//        for (WzHouseUseEntity leaveUseVo : wzHouseContracEntityList) {
//            List<WzHouseUseEntity> list;
//            if(map.get(leaveUseVo.getCity())!=null){
//                list=map.get(leaveUseVo.getCity());
//                list.add(leaveUseVo);
//            }else{
//                list=new ArrayList<>();
//                list.add(leaveUseVo);
//            }
//            map.put(leaveUseVo.getCity(),list);
//        }
//        List<WzHouseContracEntity> resultList=new ArrayList<>();
//        List<WzHouseContracEntity> cityList=new ArrayList<>();
//
//        double allContractQuantity=0l;
//        double allNoTaxContractAmount=0l;
//        double allRentArea=0l;
//        double allUnitPricePerSquareMeter=0l;
//
//        for(Map.Entry<String,List<WzHouseUseEntity>> entry:map.entrySet()){
//            List<WzHouseUseEntity> list=entry.getValue();
//            double contractQuantity=0l;
//            double noTaxContractAmount=0l;
//            double rentArea=0l;
//            double unitPricePerSquareMeter=0l;
//            for (WzHouseUseEntity leaveUseVo : list) {
//                contractQuantity+=leaveUseVo.getContractQuantity();
//                noTaxContractAmount+=leaveUseVo.getNoTaxContractAmount();
//                rentArea+=leaveUseVo.getRentArea();
//                unitPricePerSquareMeter+=leaveUseVo.getUnitPricePerSquareMeter();
//
//                allContractQuantity+=leaveUseVo.getContractQuantity();
//                allNoTaxContractAmount+=leaveUseVo.getNoTaxContractAmount();
//                allRentArea+=leaveUseVo.getRentArea();
//                allUnitPricePerSquareMeter+=leaveUseVo.getUnitPricePerSquareMeter();
//            }
//            cityList.add(list.get(0));
//        }
//        province.setContractQuantity(allContractQuantity);
//        province.setNoTaxContractAmount(formatDouble(allNoTaxContractAmount));
//        province.setRentArea(allRentArea);
//        province.setUnitPricePerSquareMeter(formatDouble(allUnitPricePerSquareMeter));
//        province.setChildren(cityList);
//        resultList.add(province);
//
//
//        List<Object> colList=new ArrayList();;
//        List<Object[]> allList = new ArrayList();
//        for (int i = 0; i < resultList.size(); i++) {
//
//            if(resultList.get(i).getCity().contains("省")){
//                colList = new ArrayList();
//                colList.add(resultList.get(i).getCity());
//                colList.add("");
//                colList.add(resultList.get(i).getContractQuantity());
//                colList.add(resultList.get(i).getNoTaxContractAmount());
//                colList.add(resultList.get(i).getRentArea());
//                colList.add(resultList.get(i).getUnitPricePerSquareMeter());
//                allList.add(colList.toArray());
//
//                //处理城市的
//                List<WzHouseContracEntity> cityList1=resultList.get(i).getChildren();
//                for (WzHouseContracEntity floorNoUserVo : cityList1) {
//                    colList = new ArrayList();
//                    colList.add("");
//                    colList.add(floorNoUserVo.getCity());
//                    colList.add(floorNoUserVo.getContractQuantity());
//                    colList.add(floorNoUserVo.getNoTaxContractAmount());
//                    colList.add(floorNoUserVo.getRentArea());
//                    colList.add(resultList.get(i).getUnitPricePerSquareMeter());
//                    allList.add(colList.toArray());
//                }
//            }
//        }
//        String[] header = new String[]{
//                "资产所属单位(一级)",
//                "资产所属单位(二级)",
//                "合同数量",
//                "不含税合同额(元)",
//                "出租面积(平米)",
//                "每平米单价(元)"
//        };
//        ee1.addSheetByArray(df.format(new Date()) + "清单", allList, header);
//    }

    public void responseTab2(DateFormat df, ExcelExport ee1, Map<String, Object> map1){




    }

    public double formatDouble(double num){
        double avera=0l;
        try{
            DecimalFormat format2 = new DecimalFormat("#.00");
            String str2 = format2.format(num);
            avera = Double.parseDouble(str2);
        }catch (Exception e){
            e.printStackTrace();
        }
        return avera;
    }

}
