package com.example.controller.house;

import com.example.common.PageVo;
import com.example.common.Rsp;
import com.example.pojo.dto.ListBuildingHighRepairDto;
import com.example.pojo.dto.ListBuildingHighSporadicRepairDto;
import com.example.pojo.dto.ListBuildingSameRepairFrequencyDto;
import com.example.pojo.dto.ListSiteNameDto;
import com.example.pojo.dto.ListSiteNumDto;
import com.example.pojo.vo.ListBuildingHighRepairVo;
import com.example.pojo.vo.ListBuildingHighSporadicRepairVo;
import com.example.pojo.vo.ListBuildingSameRepairFrequencyVo;
import com.example.service.house.HouseWzHouseMaintenaCostService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;

@Tag(name = "不动产管理策略-维修异常监控")
@Slf4j
@RequestMapping("/house-car/house/dist/api/wzHouseMaintenaCost")
@RestController
public class HouseWzHouseMaintenaCostController {
    private final HouseWzHouseMaintenaCostService houseWzHouseMaintenaCostService;

    public HouseWzHouseMaintenaCostController(HouseWzHouseMaintenaCostService houseWzHouseMaintenaCostService) {
        this.houseWzHouseMaintenaCostService = houseWzHouseMaintenaCostService;
    }

    @Operation(summary = "高总价统计")
    @PostMapping("/queryHighPrice")
    public Rsp<PageVo<ListBuildingHighRepairVo>> queryHighPrice(@Valid @RequestBody ListBuildingHighRepairDto dto) {
        return houseWzHouseMaintenaCostService.queryHighPrice(dto);
    }

    @Operation(summary = "高总价统计导出")
    @GetMapping("/queryHighPriceExport")
    public void queryHighPriceExport(@Valid ListBuildingHighRepairDto dto) {
        houseWzHouseMaintenaCostService.queryHighPriceExport(dto);
    }

    @Operation(summary = "相同维修频次统计")
    @PostMapping("/queryHighFrequency")
    public Rsp<PageVo<ListBuildingSameRepairFrequencyVo>> queryHighFrequency(@Valid @RequestBody ListBuildingSameRepairFrequencyDto dto) {
        return houseWzHouseMaintenaCostService.queryHighFrequency(dto);
    }

    @Operation(summary = "相同维修频次统计导出")
    @GetMapping("/queryHighFrequencyExport")
    public void queryHighFrequencyExport(@Valid ListBuildingSameRepairFrequencyDto dto) {
        houseWzHouseMaintenaCostService.queryHighFrequencyExport(dto);
    }

    @Operation(summary = "高额日常零星维修")
    @PostMapping("/queryDailyModify")
    public Rsp<PageVo<ListBuildingHighSporadicRepairVo>> queryDailyModify(@Valid @RequestBody ListBuildingHighSporadicRepairDto dto) {
        return houseWzHouseMaintenaCostService.queryDailyModify(dto);
    }

    @Operation(summary = "高额日常零星维修导出")
    @GetMapping("/queryDailyModifyExport")
    public void queryDailyModifyExport(@Valid ListBuildingHighSporadicRepairDto dto) {
        houseWzHouseMaintenaCostService.queryDailyModifyExport(dto);
    }

    @Operation(summary = "查询局址别名列表")
    @PostMapping("/getBuildingNameAlias")
    public Rsp<PageVo<String>> listSiteName(@RequestBody ListSiteNameDto dto) {
        return houseWzHouseMaintenaCostService.listSiteName(dto);
    }

    @Operation(summary = "查询局址编号列表")
    @PostMapping("/getBuildingNameCode")
    public Rsp<PageVo<String>> listSiteNum(@RequestBody ListSiteNumDto dto) {
        return houseWzHouseMaintenaCostService.listSiteNum(dto);
    }
}
