package com.example.dao;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.example.config.mybatis.ex.method.ExBaseMapper;
import com.example.entity.OtnAreaEntity;
import com.example.entity.house.HouseSitePo;
import com.example.pojo.bo.ListHouseSiteBo;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Select;

import java.util.List;

@Mapper
public interface WzOtnAreaDao extends ExBaseMapper<OtnAreaEntity> {
    /**
     * 根据父级组织机构id查询子组织机构
     * @param parentId 父级组织机构id
     */
    @Select("""
select
    id,
    '河北' as province,
    name,
    grade as level,
    order_num as weight,
    parent_id
from
    common.organization
where
    unhide = 1
    and parent_id = #{parentId}
order by
    order_num
""")
    List<OtnAreaEntity> listByParentId(@Param("parentId") String parentId);

    /**
     * 根据id查询组织机构
     * @param id 组织机构id
     */
    @Select("""
select
    id,
    '河北' as province,
    name,
    grade as level,
    order_num as weight,
    parent_id
from
    common.organization
where
    unhide = 1
    and id = #{id}
""")
    OtnAreaEntity getById(@Param("id") String id);

    /**
     * 根据组织机构名称查询组织机构
     * @param name 组织机构名称
     */
    @Select("""
select
    id,
    '河北' as province,
    name,
    grade as level,
    order_num as weight,
    parent_id
from
    common.organization
where
    unhide = 1
    and name = #{name}
limit 1
""")
    OtnAreaEntity getByName(@Param("name") String name);

    List<OtnAreaEntity> getCityOption(Long parentId);

    OtnAreaEntity queryObjectById(Long id);
//     List<WzHouseContractVo> queryVoList(Map<String, Object> map);
//
//     List<FloorNoUserVo> queryLeaveUseList(Map<String, Object> map);

    /**
     * 查询局址列表
     */
    @Select("""
<script>
select
    site_id,
    site_num,
    site_name
from
    house.site_month
where
    year_month = (select max(year_month) from house.site_month)
<if test="bo.areaNo != null and bo.areaNo != ''">
  and area_no = #{bo.areaNo}
</if>
<if test="bo.cityNo != null and bo.cityNo != ''">
  and city_no = #{bo.cityNo}
</if>
<if test="bo.siteNum != null and bo.siteNum != ''">
  and site_num like #{bo.siteNum} || '%'
</if>
<if test="bo.siteName != null and bo.siteName != ''">
  and site_name like '%' || #{bo.siteName} || '%'
</if>
order by site_id
</script>
""")
    List<HouseSitePo> listHouseSite(Page<HouseSitePo> page, @Param("bo") ListHouseSiteBo bo);
}
