package com.example.entity.house;

import lombok.Data;

import java.math.BigDecimal;
import java.math.RoundingMode;
import java.util.ArrayList;
import java.util.List;

@Data
public class BuildingIdleStatPo {
    /**
     * 二级组织机构编码
     */
    private String areaNo;
    /**
     * 二级组织机构名称
     */
    private String areaName;
    /**
     * 三级组织机构编码
     */
    private String cityNo;
    /**
     * 三级组织机构名称
     */
    private String cityName;
    /**
     * 闲置建筑数量
     */
    private Integer idleCount;
    /**
     * 建筑面积
     */
    private BigDecimal buildingAreaSum;
    /**
     * 建筑面积自用
     */
    private BigDecimal buildingAreaSelfUseSum;
    /**
     * 建筑面积出租
     */
    private BigDecimal buildingAreaRentSum;
    /**
     * 建筑面积闲置
     */
    private BigDecimal buildingAreaIdleSum;
    /**
     * 闲置率
     */
    private BigDecimal idlePercent;
    /**
     * 子列表
     */
    private List<BuildingIdleStatPo> children;

    public BuildingIdleStatPo() {
        this.areaNo = "";
        this.areaName = "";
        this.cityNo = "";
        this.cityName = "";
        this.idleCount = 0;
        this.buildingAreaSum = BigDecimal.ZERO;
        this.buildingAreaSelfUseSum = BigDecimal.ZERO;
        this.buildingAreaRentSum = BigDecimal.ZERO;
        this.buildingAreaIdleSum = BigDecimal.ZERO;
        this.idlePercent = BigDecimal.ZERO;
        this.children = new ArrayList<>();
    }

    public BuildingIdleStatPo(String areaNo, String areaName) {
        this.areaNo = areaNo;
        this.areaName = areaName;
        this.cityNo = areaNo;
        this.cityName = areaName;
        this.idleCount = 0;
        this.buildingAreaSum = BigDecimal.ZERO;
        this.buildingAreaSelfUseSum = BigDecimal.ZERO;
        this.buildingAreaRentSum = BigDecimal.ZERO;
        this.buildingAreaIdleSum = BigDecimal.ZERO;
        this.idlePercent = BigDecimal.ZERO;
        this.children = new ArrayList<>();
    }

    public void update(BuildingIdleStatPo po) {
        this.idleCount = this.idleCount + po.idleCount;
        this.buildingAreaSum = this.buildingAreaSum.add(po.buildingAreaSum);
        this.buildingAreaSelfUseSum = this.buildingAreaSelfUseSum.add(po.buildingAreaSelfUseSum);
        this.buildingAreaRentSum = this.buildingAreaRentSum.add(po.buildingAreaRentSum);
        this.buildingAreaIdleSum = this.buildingAreaIdleSum.add(po.buildingAreaIdleSum);
        if (BigDecimal.ZERO.compareTo(this.buildingAreaRentSum.add(this.buildingAreaIdleSum)) != 0) {
            this.idlePercent = this.buildingAreaIdleSum
                    .divide(this.buildingAreaRentSum.add(this.buildingAreaIdleSum), 4, RoundingMode.HALF_DOWN);
        } else {
//            this.idlePercent = null;
            this.idlePercent = BigDecimal.ZERO;
        }
        this.children.add(po);
    }
}
