package com.example.service.house;

import cn.hutool.core.net.URLEncodeUtil;
import com.example.common.PageVo;
import com.example.common.Rsp;
import com.example.dao.house.HouseBuildingDao;
import com.example.entity.house.BuildingOfficeAreaStatPo;
import com.example.pojo.bo.BuildingOfficeAreaStatBo;
import com.example.pojo.dto.BuildingOfficeAreaStatDto;
import com.example.pojo.vo.BuildingOfficeAreaStatVo;
import lombok.extern.slf4j.Slf4j;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.CellStyle;
import org.apache.poi.ss.usermodel.DataFormat;
import org.apache.poi.ss.usermodel.HorizontalAlignment;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.VerticalAlignment;
import org.apache.poi.xssf.streaming.SXSSFSheet;
import org.apache.poi.xssf.streaming.SXSSFWorkbook;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;
import org.springframework.util.StringUtils;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

import javax.servlet.http.HttpServletResponse;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.Collections;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.concurrent.atomic.AtomicInteger;
import java.util.stream.Stream;

@Slf4j
@Service
public class HouseWzBuildmanageAvageareaService {
    private final HouseBuildingDao houseBuildingDao;

    public HouseWzBuildmanageAvageareaService(HouseBuildingDao houseBuildingDao) {
        this.houseBuildingDao = houseBuildingDao;
    }

    public Rsp<PageVo<BuildingOfficeAreaStatVo>> buildingOfficeAreaStat(BuildingOfficeAreaStatDto dto) {
        BuildingOfficeAreaStatPo buildingOfficeAreaStatPos = getBuildingOfficeAreaStatPos(dto);
        if (buildingOfficeAreaStatPos == null) {
            return Rsp.ok();
        }
        BuildingOfficeAreaStatVo vo = new BuildingOfficeAreaStatVo(buildingOfficeAreaStatPos, false);
        PageVo<BuildingOfficeAreaStatVo> pageVo = new PageVo<>(Collections.singletonList(vo));
        return Rsp.ok(pageVo);
    }

    private BuildingOfficeAreaStatPo getBuildingOfficeAreaStatPos(BuildingOfficeAreaStatDto dto) {
        BuildingOfficeAreaStatBo bo = new BuildingOfficeAreaStatBo();
        if (dto.getMap() != null && dto.getMap().getStatisticalMonth() != null) {
            bo.setYearMonth(dto.getMap().getStatisticalMonth());
        }
        if (dto.getMap() != null && StringUtils.hasText(dto.getMap().getCity()) && !"全省".equals(dto.getMap().getCity())) {
            bo.setAreaNo(dto.getMap().getCity());
        }
        if (dto.getMap() != null && StringUtils.hasText(dto.getMap().getCounty())) {
            bo.setCityNo(dto.getMap().getCounty());
        }
        // 查询三级单位统计
        List<BuildingOfficeAreaStatPo> buildingOfficeAreaStatPos = houseBuildingDao.buildingOfficeAreaStat(bo);
        if (CollectionUtils.isEmpty(buildingOfficeAreaStatPos)) {
            return null;
        }
        // 一级单位统计
        BuildingOfficeAreaStatPo firstUnitPo = new BuildingOfficeAreaStatPo();
        firstUnitPo.setAreaName("全省");
        firstUnitPo.setCityName("全省");
        LinkedHashMap<String, BuildingOfficeAreaStatPo> secondUnitPoMap = new LinkedHashMap<>();
        // 二级单位统计
        for (BuildingOfficeAreaStatPo po : buildingOfficeAreaStatPos) {
            secondUnitPoMap.putIfAbsent(po.getAreaNo(),
                    new BuildingOfficeAreaStatPo(po.getAreaNo(), po.getAreaName()));
            BuildingOfficeAreaStatPo secondUnitPo = secondUnitPoMap.get(po.getAreaNo());
            secondUnitPo.update(po);
        }
        for (BuildingOfficeAreaStatPo value : secondUnitPoMap.values()) {
            firstUnitPo.update(value);
        }
        return firstUnitPo;
    }

    public void buildingOfficeAreaStatExport(BuildingOfficeAreaStatDto.BuildingOfficeAreaStatMapDTO dto) {
        ServletRequestAttributes servletRequestAttributes = (ServletRequestAttributes) RequestContextHolder
                .getRequestAttributes();
        if (servletRequestAttributes == null) {
            return;
        }
        HttpServletResponse response = servletRequestAttributes.getResponse();
        if (response == null) {
            return;
        }
        String filename = "房屋管理_自有房产人均办公面积"
                + LocalDateTime.now().format(DateTimeFormatter.ofPattern("yyyyMMdd")) + ".xlsx";
        response.setHeader("Content-Disposition", "attachment;filename=" + URLEncodeUtil.encode(filename));
        response.setContentType("application/octet-stream");
        try (SXSSFWorkbook wb = new SXSSFWorkbook()) {
            writeBuildingOfficeAreaStat(new BuildingOfficeAreaStatDto(dto), wb);
            wb.write(response.getOutputStream());
        } catch (Exception e) {
            log.error(e.getMessage(), e);
        }
    }

    /**
     * 写自有房产人均办公面积统计文件
     */
    private void writeBuildingOfficeAreaStat(BuildingOfficeAreaStatDto dto, SXSSFWorkbook wb) {
        BuildingOfficeAreaStatPo firstPo = getBuildingOfficeAreaStatPos(dto);
        DataFormat dataFormat = wb.createDataFormat();
        // 整数样式
        CellStyle integerCellStyle = wb.createCellStyle();
        integerCellStyle.setDataFormat(dataFormat.getFormat("#,##0"));
        integerCellStyle.setAlignment(HorizontalAlignment.RIGHT);
        // 数字样式
        CellStyle numberCellStyle = wb.createCellStyle();
        numberCellStyle.setDataFormat(dataFormat.getFormat("#,##0.00"));
        numberCellStyle.setAlignment(HorizontalAlignment.RIGHT);
        // 默认样式
        CellStyle baseCellStyle = wb.createCellStyle();
        baseCellStyle.setAlignment(HorizontalAlignment.CENTER);
        baseCellStyle.setVerticalAlignment(VerticalAlignment.CENTER);
        SXSSFSheet sheet = wb.createSheet();
        AtomicInteger rowIndex = new AtomicInteger(0);
        // 表头
        Row headerRow = sheet.createRow(rowIndex.getAndIncrement());
        List<String> headers = Stream.of("资产所属单位(一级)", "资产所属单位(二级)", "资产所属单位(三级)",
                "建筑面积-自有办公面积(平米)", "县市的合同人员+紧密外包人员", "人均办公面积").toList();
        int headerLength = headers.size();
        for (int i = 0; i < headerLength; i++) {
            Cell cell = headerRow.createCell(i);
            cell.setCellValue(headers.get(i));
            cell.setCellStyle(baseCellStyle);
            // 根据内容长度设置列宽
            int columnWidth = headers.get(i).length() * 256 * 2 + 256;
            sheet.setColumnWidth(i, columnWidth);
        }
        if (firstPo == null) {
            return;
        }
        // 数据
        AtomicInteger columnIndex1 = new AtomicInteger(0);
        // 一级单位统计
        Row row1 = sheet.createRow(rowIndex.getAndIncrement());
        // 资产所属单位(一级)
        Cell firstUnitCell1 = row1.createCell(columnIndex1.getAndIncrement());
        if (firstPo.getAreaName() != null) {
            firstUnitCell1.setCellValue(firstPo.getAreaName());
        }
        // 二级单位
        Cell areaNameCell1 = row1.createCell(columnIndex1.getAndIncrement());
//        if (firstPo.getAreaName() != null) {
//            areaNameCell1.setCellValue(firstPo.getAreaName());
//        }
        // 三级单位
        Cell cityNameCell1 = row1.createCell(columnIndex1.getAndIncrement());
//        if (firstPo.getCityName() != null) {
//            cityNameCell1.setCellValue(firstPo.getCityName());
//        }
        // 建筑面积-自有办公面积(平米)
        Cell buildingAreaSelfUseSumCell1 = row1.createCell(columnIndex1.getAndIncrement());
        if (firstPo.getBuildingAreaSelfUseSum() != null) {
            buildingAreaSelfUseSumCell1.setCellValue(firstPo.getBuildingAreaSelfUseSum().doubleValue());
        }
        buildingAreaSelfUseSumCell1.setCellStyle(numberCellStyle);
        // 县市的合同人员+紧密外包人员
        Cell totalCell1 = row1.createCell(columnIndex1.getAndIncrement());
        if (firstPo.getTotal() != null) {
            totalCell1.setCellValue(firstPo.getTotal());
        }
        totalCell1.setCellStyle(integerCellStyle);
        // 人均办公面积
        Cell areaAvgCell1 = row1.createCell(columnIndex1.getAndIncrement());
        if (firstPo.getAreaAvg() != null) {
            areaAvgCell1.setCellValue(firstPo.getAreaAvg().doubleValue());
        }
        areaAvgCell1.setCellStyle(numberCellStyle);
        // 二级单位统计
        for (BuildingOfficeAreaStatPo secondPo : firstPo.getChildren()) {
            AtomicInteger columnIndex2 = new AtomicInteger(0);
            // 一级单位统计
            Row row2 = sheet.createRow(rowIndex.getAndIncrement());
            // 资产所属单位(一级)
            Cell firstUnitCell2 = row2.createCell(columnIndex2.getAndIncrement());
//            if (secondPo.getAreaName() != null) {
//                firstUnitCell2.setCellValue(secondPo.getAreaName());
//            }
            // 二级单位
            Cell areaNameCell2 = row2.createCell(columnIndex2.getAndIncrement());
            if (secondPo.getAreaName() != null) {
                areaNameCell2.setCellValue(secondPo.getAreaName());
            }
            // 三级单位
            Cell cityNameCell2 = row2.createCell(columnIndex2.getAndIncrement());
//            if (secondPo.getCityName() != null) {
//                cityNameCell2.setCellValue(secondPo.getCityName());
//            }
            // 建筑面积-自有办公面积(平米)
            Cell buildingAreaSelfUseSumCell2 = row2.createCell(columnIndex2.getAndIncrement());
            if (secondPo.getBuildingAreaSelfUseSum() != null) {
                buildingAreaSelfUseSumCell2.setCellValue(secondPo.getBuildingAreaSelfUseSum().doubleValue());
            }
            buildingAreaSelfUseSumCell2.setCellStyle(numberCellStyle);
            // 县市的合同人员+紧密外包人员
            Cell totalCell2 = row2.createCell(columnIndex2.getAndIncrement());
            if (secondPo.getTotal() != null) {
                totalCell2.setCellValue(secondPo.getTotal());
            }
            totalCell2.setCellStyle(integerCellStyle);
            // 人均办公面积
            Cell areaAvgCell2 = row2.createCell(columnIndex2.getAndIncrement());
            if (secondPo.getAreaAvg() != null) {
                areaAvgCell2.setCellValue(secondPo.getAreaAvg().doubleValue());
            }
            areaAvgCell2.setCellStyle(numberCellStyle);
            // 三级单位统计
            for (BuildingOfficeAreaStatPo thirdPo : secondPo.getChildren()) {
                AtomicInteger columnIndex3 = new AtomicInteger(0);
                Row row3 = sheet.createRow(rowIndex.getAndIncrement());
                // 资产所属单位(一级)
                Cell firstUnitCell3 = row3.createCell(columnIndex3.getAndIncrement());
//                if (thirdPo.getAreaName() != null) {
//                    firstUnitCell3.setCellValue(thirdPo.getAreaName());
//                }
                // 二级单位
                Cell areaNameCell3 = row3.createCell(columnIndex3.getAndIncrement());
//                if (thirdPo.getAreaName() != null) {
//                    areaNameCell3.setCellValue(thirdPo.getAreaName());
//                }
                // 三级单位
                Cell cityNameCell3 = row3.createCell(columnIndex3.getAndIncrement());
                if (thirdPo.getCityName() != null) {
                    cityNameCell3.setCellValue(thirdPo.getCityName());
                }
                // 建筑面积-自有办公面积(平米)
                Cell buildingAreaSelfUseSumCell3 = row3.createCell(columnIndex3.getAndIncrement());
                if (thirdPo.getBuildingAreaSelfUseSum() != null) {
                    buildingAreaSelfUseSumCell3.setCellValue(thirdPo.getBuildingAreaSelfUseSum().doubleValue());
                }
                buildingAreaSelfUseSumCell3.setCellStyle(numberCellStyle);
                // 县市的合同人员+紧密外包人员
                Cell totalCell3 = row3.createCell(columnIndex3.getAndIncrement());
                if (thirdPo.getTotal() != null) {
                    totalCell3.setCellValue(thirdPo.getTotal());
                }
                totalCell3.setCellStyle(integerCellStyle);
                // 人均办公面积
                Cell areaAvgCell3 = row3.createCell(columnIndex3.getAndIncrement());
                if (thirdPo.getAreaAvg() != null) {
                    areaAvgCell3.setCellValue(thirdPo.getAreaAvg().doubleValue());
                }
                areaAvgCell3.setCellStyle(numberCellStyle);
            }
        }
    }
}
